@@ -8,7 +8,7 @@ use Error::Pure qw(err);
 use File::Spec::Functions qw(catdir catfile splitdir);
 use FindBin qw($Bin $Script);
 
-our $VERSION = 0.16;
+our $VERSION = 0.17;
 
 # Constructor.
 sub new {
@@ -267,6 +267,11 @@ File::Object - Object system for filesystem paths.
  my $self = $obj->set;
  my $self = $obj->up($num);
 
+=head1 DESCRIPTION
+
+This provides an object oriented interface to file/directory paths, such as
+actual, parent or explicit directory and relative paths to them.
+
 =head1 METHODS
 
 =head2 C<new>
@@ -275,7 +280,7 @@ File::Object - Object system for filesystem paths.
 
 Constructor.
 
-Returns instance of object.
+Constructor parameters are:
 
 =over 8
 
@@ -303,6 +308,8 @@ Default value is 'dir'.
 
 =back
 
+Returns instance of object.
+
 =head2 C<dir>
 
  my $self = $obj->dir(@dir);
@@ -364,7 +371,7 @@ Returns instance of object.
 
  my $self = $obj->up($num);
 
-Go to $up_num upper directory.
+Go to upper directory/ies defined by C<$num> count. Default value is one.
 
 Returns instance of object.
 
@@ -486,6 +493,10 @@ portably perform operations on file names
 
 Cross-platform path specification manipulation
 
+=item L<Path::Tiny>
+
+File path utility
+
 =back
 
 =head1 REPOSITORY
@@ -506,6 +517,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.16
+0.17
 
 =cut
